<?php

namespace App\Http\Controllers\AdminControllers\Posts;

use App\Models\Posts\PostTypeModel;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Str;

use Image;

class PostTypeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data = PostTypeModel::orderBy('ordering', 'asc')->get();
        return view('admin.post-type.index', compact('data'));
    }

    public function index_user()
    {
        $data = PostTypeModel::orderBy('ordering', 'asc')->get();
        return view('admin.post-type.user-index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // List Posttype Template
        $fileList = scandir(resource_path('views/themes/default/'));
        $filterArray = $this->filter_template_posttype($fileList);

        $filename = array();
        foreach ($filterArray as $filterArr) {
            $filename[] = $this->remove_extention($filterArr);
        }
        $file1 = array('page' => 'Choose Template');
        foreach ($filename as $file) {
            $file1[$file] = $file;
        }
        $templates = $file1;

        $ordering = PostTypeModel::max('ordering');
        $ordering = $ordering + 1;
        return view('admin.post-type.create', compact('ordering', 'templates'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'post_type' => 'required',
            'uri' => 'required|unique:cl_post_type'
        ]);

        $medium_width = env('MEDIUM_WIDTH');
        $medium_height = env('MEDIUM_HEIGHT');
        $data = $request->all();

        $file = $request->file('banner');
        $banner = '';
        if ($request->hasfile('banner')) {
            $product = $request->file('banner')->getClientOriginalName();
            $extension = $request->file('banner')->getClientOriginalExtension();
            $product = explode('.', $product);
            $banner = Str::slug($product[0]) . '-' . Str::random(40) . '.' . $extension;

            $destinationPath_medium = public_path('uploads/medium');
            $destinationOriginal = public_path('uploads/original');

            $banner_picture = Image::make($file->getRealPath());
            $width = Image::make($file->getRealPath())->width();
            $height = Image::make($file->getRealPath())->height();

            $banner_picture->save($destinationOriginal . '/' . $banner);
            $banner_picture->resize($medium_width, $medium_height, function ($constraint) {
                $constraint->aspectRatio();
            })->save($destinationPath_medium . '/' . $banner);

            /*Upload Original Image*/
            // $banner_picture->resize($width, $height, function($constraint){
            //   $constraint->aspectRatio();
            // })->save($destinationOriginal .'/'. $banner );
        }

        $file1 = $request->file('featured');
        $featured = '';
        if ($request->hasfile('featured')) {
            $product = $request->file('featured')->getClientOriginalName();
            $extension = $request->file('featured')->getClientOriginalExtension();
            $product = explode('.', $product);
            $featured = Str::slug($product[0]) . '-' . Str::random(40) . '.' . $extension;

            $destinationPath_medium = public_path('uploads/medium');
            $destinationOriginal = public_path('uploads/original');

            $featured_picture = Image::make($file1->getRealPath());
            $width = Image::make($file1->getRealPath())->width();
            $height = Image::make($file1->getRealPath())->height();

            $featured_picture->save($destinationOriginal . '/' . $featured);
            $featured_picture->resize($medium_width, $medium_height, function ($constraint) {
                $constraint->aspectRatio();
            })->save($destinationPath_medium . '/' . $featured);

            /*Upload Original Image*/
            // $featured_picture->resize($width, $height, function($constraint){
            //   $constraint->aspectRatio();
            // })->save($destinationOriginal .'/'. $featured );
        }

        $data['banner'] = $banner;
        $data['featured'] = $featured;
        $data['content'] = $request->contents;
        $data['uri'] = Str::slug($request->uri);
        $result = PostTypeModel::create($data);
        if ($result) {
            return redirect()->back()->with('message', 'Stored Successfully.');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param \App\Models\Posts\PostTypeModel $postTypeModel
     * @return \Illuminate\Http\Response
     */
    public function show(PostTypeModel $postTypeModel)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param \App\Models\Posts\PostTypeModel $postTypeModel
     * @return \Illuminate\Http\Response
     */
    public function edit(PostTypeModel $postTypeModel, $posttype, $id)
    {

        // List Posttype Template
        $fileList = scandir(resource_path('views/themes/default/'));
        $filterArray = $this->filter_template_posttype($fileList);

        $filename = array();
        foreach ($filterArray as $filterArr) {
            $filename[] = $this->remove_extention($filterArr);
        }
        $file1 = array('page' => 'Choose Template');
        foreach ($filename as $file) {
            $file1[$file] = $file;
        }
        $templates = $file1;

        $data = PostTypeModel::find($id);
        return view('admin.post-type.edit', compact('data', 'templates'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\Posts\PostTypeModel $postTypeModel
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, PostTypeModel $postTypeModel, $posttype, $id)
    {
        $request->validate([
            'post_type' => 'required',
            'uri' => 'required'
        ]);
        $medium_width = env('MEDIUM_WIDTH');
        $medium_height = env('MEDIUM_HEIGHT');
        $data = PostTypeModel::find($id);
        $product_name = '';
        $featured_name = '';

        $file = $request->file('banner');
        $file1 = $request->file('featured');

        if ($request->hasfile('banner')) {
            $data = PostTypeModel::find($id);
            if ($data->banner) {
                if (file_exists(env('PUBLIC_PATH') . 'uploads/medium/' . $data->banner)) {
                    unlink(env('PUBLIC_PATH') . 'uploads/medium/' . $data->banner);
                }
                if (file_exists(env('PUBLIC_PATH') . 'uploads/original/' . $data->banner)) {
                    unlink(env('PUBLIC_PATH') . 'uploads/original/' . $data->banner);
                }
            }
            $product = $request->file('banner')->getClientOriginalName();
            $extension = $request->file('banner')->getClientOriginalExtension();
            $product = explode('.', $product);
            $product_name = Str::slug($product[0]) . '-' . Str::random(40) . '.' . $extension;

            $destinationPath_medium = public_path('uploads/medium');
            $destinationOriginal = public_path('uploads/original');

            $product_picture = Image::make($file->getRealPath());
            $width = Image::make($file->getRealPath())->width();
            $height = Image::make($file->getRealPath())->height();

            $product_picture->save($destinationOriginal . '/' . $product_name);
            $product_picture->resize($medium_width, $medium_height, function ($constraint) {
                $constraint->aspectRatio();
            })->save($destinationPath_medium . '/' . $product_name);

            /*Upload Original Image*/
            // $product_picture->resize($width, $height, function($constraint){
            //   $constraint->aspectRatio();
            // })->save($destinationOriginal .'/'. $product_name );

            $data->banner = $product_name;
        }

        if ($request->hasfile('featured')) {
            $data = PostTypeModel::find($id);
            if ($data->featured) {
                if (file_exists(env('PUBLIC_PATH') . 'uploads/medium/' . $data->featured)) {
                    unlink(env('PUBLIC_PATH') . 'uploads/medium/' . $data->featured);
                }
                if (file_exists(env('PUBLIC_PATH') . 'uploads/original/' . $data->featured)) {
                    unlink(env('PUBLIC_PATH') . 'uploads/original/' . $data->featured);
                }
            }
            $product = $request->file('featured')->getClientOriginalName();
            $extension = $request->file('featured')->getClientOriginalExtension();
            $product = explode('.', $product);
            $featured_name = Str::slug($product[0]) . '-' . Str::random(40) . '.' . $extension;

            $destinationPath_medium = public_path('uploads/medium');
            $destinationOriginal = public_path('uploads/original');

            $product_picture = Image::make($file1->getRealPath());
            $width = Image::make($file1->getRealPath())->width();
            $height = Image::make($file1->getRealPath())->height();

            $product_picture->save($destinationOriginal . '/' . $featured_name);
            $product_picture->resize($medium_width, $medium_height, function ($constraint) {
                $constraint->aspectRatio();
            })->save($destinationPath_medium . '/' . $featured_name);

            /*Upload Original Image*/
            // $product_picture->resize($width, $height, function($constraint){
            //   $constraint->aspectRatio();
            // })->save($destinationOriginal .'/'. $featured_name );

            $data->featured = $featured_name;
        }

        $data->post_type = $request->post_type;
        $data->caption = $request->caption;
        $data->meta_keyword = $request->meta_keyword;
        $data->meta_description = $request->meta_description;
        $data->content = $request->contents;
        $data->uri = Str::slug($request->uri);
        $data->template = $request->template;
        $data->uid = $request->uid;
        $data->ordering = $request->ordering;
        $data->is_menu = $request->is_menu;
        $data->save();
        return redirect()->back()->with('message', 'Update Successful.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\Models\Posts\PostTypeModel $postTypeModel
     * @return \Illuminate\Http\Response
     */
    public function destroy(PostTypeModel $postTypeModel, $posttype, $id)
    {
        $data = PostTypeModel::find($id);
        if ($data->banner) {
            if (file_exists(env('PUBLIC_PATH') . 'uploads/medium/' . $data->banner)) {
                unlink(env('PUBLIC_PATH') . 'uploads/medium/' . $data->banner);
            }
            if (file_exists(env('PUBLIC_PATH') . 'uploads/original/' . $data->banner)) {
                unlink(env('PUBLIC_PATH') . 'uploads/original/' . $data->banner);
            }
        }
        $data->delete();
    }

    // Filter Template Child
    private function filter_template_posttype($template)
    {
        $tmpl2 = array();
        if (!empty($template)) {
            foreach ($template as $tmpl) {
                if (strpos($tmpl, "posttypeTemplate-") !== false) {
                    $tmpl2[] = $tmpl;
                }
            }
        }
        return $tmpl2;
    }

    // Remove Extention
    private function remove_extention($filename)
    {
        $exp = explode('.', $filename);
        $file = $exp[0];
        return $file;
    }

 // Delete Post Thumbnail
    function delete_posttype_thumb(PostTypeModel $postModel, $id){
     $data = PostTypeModel::find($id);
     if($data->banner){
      if(file_exists(env('PUBLIC_PATH').'uploads/medium/' . $data->banner)){
        unlink(env('PUBLIC_PATH').'uploads/medium/' . $data->banner);
      }
      if(file_exists(env('PUBLIC_PATH').'uploads/original/' . $data->banner)){
        unlink(env('PUBLIC_PATH').'uploads/original/' . $data->banner);
      }
    }
    $data->banner = NULL;
    $data->save();
    return response('Delete Successful.');
  }

  // Delete Post Featured
  function delete_posttype_featured(PostTypeModel $postModel, $id){
    $data = PostTypeModel::find($id);
    if($data->featured){
     if(file_exists(env('PUBLIC_PATH').'uploads/medium/' . $data->featured)){
       unlink(env('PUBLIC_PATH').'uploads/medium/' . $data->featured);
     }
     if(file_exists(env('PUBLIC_PATH').'uploads/original/' . $data->featured)){
       unlink(env('PUBLIC_PATH').'uploads/original/' . $data->featured);
     }
   }
   $data->featured = NULL;
   $data->save();
   return response('Delete Successful.');
 }
  
}
