<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Posts\PostModel;
use App\Models\Posts\AssociatedPostModel;
use App\Models\Posts\PostTypeModel;
use App\Models\Galleries\ImageGalleryModel;
use App\Models\Galleries\ImageGalleryCategoryModel;
use App\Models\Banners\BannerModel;
use App\Models\Galleries\ImageModel;
use App\Models\Settings\SettingModel;


class FrontController extends Controller
{
    public function pagedetail($uri){
    if(!check_uri($uri)){
      abort(404); 
    }
    $data = PostModel::where('uri',$uri)->orWhere('page_key',$uri)->first();
     $domainUrl = get_current_domain();

    $data_child = PostModel::where(['post_parent'=>$data['id'],'status'=>'1'])->orderBy('post_order','asc')->get();
      if($data->page_thumbnail ?? []){
                $data->page_thumbnail = $domainUrl.'/uploads/medium/'.$data->page_thumbnail;
            }
                    foreach($data_child as $post){
            if($post->page_thumbnail){
                $post->page_thumbnail = $domainUrl.'/uploads/medium/'.$post->page_thumbnail;
            }
                    }
    $inner_details = [
        'data' => $data,
        'data_child' => $data_child
    ];

    return response()->json(['inner_details'=>$inner_details]);

}

public function child_associated($uri)
{
    $data = PostModel::where('uri',$uri)->orWhere('page_key',$uri)->first();
    $data2 = AssociatedPostModel::where('post_id', $data['id'])->orderBy('ordering','asc')->get();
   
  return response()->json(['data2'=>$data2]);
}


 public function posttype(Request  $request,$uri){
    if(!check_posttype_uri($uri)){
        abort(404);
    }
    $data=PostTypeModel::where('uri',$uri)->first();
    $domainUrl = get_current_domain();
    if($data->banner){
        $data->banner = $domainUrl.'/uploads/medium/'.$data->banner;
    }

    if($data)
    {
        $posts = PostModel::where(['post_type'=>$data->id,'post_parent'=>0,'status'=>'1'])->orderBy('post_order','asc')->get();
        foreach($posts as $post){
            if($post->page_thumbnail){
                $post->page_thumbnail = $domainUrl.'/uploads/medium/'.$post->page_thumbnail;
            }
            if($post->post_date){
                $date = $post->post_date;
                // Convert the date to a Unix timestamp
                $timestamp = strtotime($date);
                // Format the timestamp in 'F d, Y' format
                $post->date = date('F d, Y', $timestamp);
            }
        }
        $first = PostModel::where(['post_type'=>$data->id,'status'=>'1'])->orderBy('post_order','desc')->first();
        $documents = ImageGalleryCategoryModel::orderBy('id','desc')->get();
    
        foreach($documents as $document){
            if($document->picture){
                $document->picture = $domainUrl.'/uploads/galleries/'.$document->picture;
            }
        }
        $partners = BannerModel::orderBy('id','desc')->get();
        foreach($partners as $partner){
            $partner->picture = $domainUrl.'/uploads/banners/'.$partner->picture;
        }
    }
    return response()->json(['domain'=>$domainUrl,'data'=>$data,'posts'=>$posts, 'documents'=>$documents, 'partners' => $partners]);

  }
  
    public function pagechild($uri)
  {
   
 
      $data = PostModel::where('uri',$uri)->orWhere('page_key',$uri)->first();
      $domainUrl = get_current_domain();
      $data2 = PostModel::where(['post_parent'=>$data['id'],'status'=>'1'])->orderBy('post_order','desc')->paginate(12);
      $ids=$data2->pluck('id');
    
        foreach($data2 as $post){
            if($post->page_thumbnail ?? []){
                $post->page_thumbnail = $domainUrl.'/uploads/medium/'.$post->page_thumbnail;
            }
            if($post->created_at){
                $date = $post->created_at;
                // Convert the date to a Unix timestamp
                $timestamp = strtotime($date);
                // Format the timestamp in 'F d, Y' format
                $post->date = date('Y-m-d', $timestamp);
            }
        }
        
      $associated = AssociatedPostModel::whereIn('post_id', $ids)->orderBy('ordering','asc')->get();
      $child_details = [
        'child_data'=>$data2,
        'associated'=>$associated
    ];


      return response()->json(['child_details'=>$child_details]);

  }
  
  
  
   public function associated($uri)
  {
   
      $data = PostModel::where('uri',$uri)->orWhere('page_key',$uri)->first();
     
      $associated_posts = AssociatedPostModel::where('post_id', $data['id'])->orderBy('ordering','asc')->paginate(6);

      return response()->json(['associated_post'=>$associated_posts]);

  }
  
   public function navigations()
  {
    $data=PostTypeModel::where(['is_menu'=>'1'])->orderBy('ordering','asc')->get();
    return response()->json(['data'=>$data]);
  }
  
    public function gallery(){

         $domainUrl = get_current_domain();
        $galleries = ImageGalleryModel::orderBy('id','desc')->paginate(6);
        foreach($galleries as $gallery){
            $gallery->picture = $domainUrl.'/uploads/galleries/'.$gallery->picture;
        }
        return response()->json(['galleries'=>$galleries]);
    }
    
      public function child_detail($uri)
  {
       $domainUrl = get_current_domain();
       $data = PostModel::where('uri',$uri)->orWhere('page_key',$uri)->first();
        if($data->page_thumbnail ?? []){
                $data->page_thumbnail = $domainUrl.'/uploads/medium/'.$data->page_thumbnail;
            }
       $fotos = ImageModel::where('post_id',$data->id)->get();
       $images= $fotos ? $fotos : '';
   
      foreach($images as $img){
            $img->path = $domainUrl.'/uploads/original/'.$img->image;
        }
    $child_details = [
        'data' => $data,
        'images' => $images
    ];
   
    return response()->json(['child_details'=>$child_details]);

  }
  
  public function setting()
  {
      $data=SettingModel::where('id',1)->first();
      return response()->json(['data'=>$data]);
  }
}
